#!/bin/bash -e

  export COMPSS_PYTHON_VERSION=3.9.10
  module load COMPSs/3.3

  # Define script variables
  scriptDir=$(pwd)/$(dirname $0)
  execFile=${scriptDir}/src/wc_reduce.py
  appPythonpath=${scriptDir}/src/

  # Retrieve arguments
  numNodes=$1
  executionTime=$2
  tracing=$3

  # Leave application args on $@
  shift 3

  # Enqueue the application
  pycompss job submit \
    --provenance \
    --qos=debug \
    --num_nodes=$numNodes \
    --exec_time=$executionTime \
    --master_working_dir=$(pwd) \
    --worker_working_dir=local_disk \
    --tracing=$tracing \
    --graph=true \
    --pythonpath=$appPythonpath \
    --lang=python \
    $execFile $@



######################################################
# APPLICATION EXECUTION EXAMPLE
# Call:
#       ./launch_wordcount.sh numNodes executionTime tracing datset_path
#
# Example:
#       ./launch_wordcount.sh 2 10 false /home/nct00/nct00006/dataset/dataset_64f_16mb/
#####################################################
